# bounciepy

# bounciepy
[![CI - Main](https://github.com/mandarons/bounciepy/actions/workflows/ci-main-test-coverage.yml/badge.svg)](https://github.com/mandarons/bounciepy/actions/workflows/ci-main-test-coverage.yml)
[![Tests](https://mandarons.github.io/bounciepy/badges/tests.svg)](https://mandarons.github.io/bounciepy/test-results/)
[![Coverage](https://mandarons.github.io/bounciepy/badges/coverage.svg)](https://mandarons.github.io/bounciepy/test-coverage/index.html)
[![Discord](https://img.shields.io/discord/871555550444408883?style=for-the-badge)](https://discord.gg/HfAXY2ykhp)
<a href="https://www.buymeacoffee.com/mandarons" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" style="height: 30px !important;width: 150px !important;box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;-webkit-box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;" ></a>

:love_you_gesture: ***Please star this repository if you end up using the library. It will help me continue supporting this product.*** :pray:

